<?php
/***************************************************************
*  Copyright notice
*
*  (c) Sven Burkert (bedienung@sbtheke.de)
*  All rights reserved
*
*  This script is part of the TYPO3 project. The TYPO3 project is
*  free software; you can redistribute it and/or modify
*  it under the terms of the GNU General Public License as published by
*  the Free Software Foundation; either version 2 of the License, or
*  (at your option) any later version.
*
*  The GNU General Public License can be found at
*  http://www.gnu.org/copyleft/gpl.html.
*  A copy is found in the textfile GPL.txt and important notices to the license
*  from the author is found in LICENSE.txt distributed with these scripts.
*
*
*  This script is distributed in the hope that it will be useful,
*  but WITHOUT ANY WARRANTY; without even the implied warranty of
*  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*  GNU General Public License for more details.
*
*  This copyright notice MUST APPEAR in all copies of the script!
***************************************************************/

	// Make sure that we are executed only in TYPO3 context
if(!defined('TYPO3_MODE')) {
	die('Access denied.');
}


/**
 * class providing configuration checks for immoscout2ttnews.
 *
 * @author	Sven Burkert <bedienung@sbtheke.de>
 *
 * @package	TYPO3
 * @subpackage	tx_immoscout2ttnews
 */
class tx_immoscout2ttnews_emconfhelper {

	private function init() {
		$this->extConf = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['immoscout2ttnews']);
		$GLOBALS['LANG']->includeLLFile('EXT:immoscout2ttnews/locallang.xml');
	}

	/**
	 * Checks the backend configuration and shows a message if necessary.
	 *
	 * @param	array				$params: Field information to be rendered
	 * @param	t3lib_tsStyleConfig	$pObj: The calling parent object.
	 * @return	string				Messages as HTML if something needs to be reported
	 */
	public function checkAuth(array $params, t3lib_tsStyleConfig $pObj) {
		$this->init();

		if($this->extConf['basic.']['key'] && $this->extConf['basic.']['secret']) {
			// load SDK
			require_once(t3lib_extMgm::extPath('immoscout2ttnews') . 'Immocaster/Sdk.php');

			$oImmocaster = Immocaster_Sdk::getInstance(
				'is24',
				$this->extConf['basic.']['key'],
				$this->extConf['basic.']['secret']
			);

			// use cUrl
			if($GLOBALS['TYPO3_CONF_VARS']['SYS']['curlUse'] == 1) {
				$oImmocaster->setReadingType('curl');
			}

			// work on live
			if($this->extConf['basic.']['live']) {
				$oImmocaster->setRequestUrl('live');
			}

			// connect to DB
			$oImmocaster->setDataStorage(array(
				'mysql',
				TYPO3_db_host,
				TYPO3_db_username,
				TYPO3_db_password,
				TYPO3_db
			));

			// is there another way to check that user has authenticated application?
			if(!$oImmocaster->oDataStorage->getApplicationToken()) {
				$aParameter = array(
					'callback_url' => t3lib_div::getIndpEnv('TYPO3_REQUEST_HOST') . '/typo3/mod.php?M=tools_em&CMD[showExt]=immoscout2ttnews&SET[singleDetails]=info',
					'verifyApplication' => true
				);
				if($oImmocaster->getAccess($aParameter)) {
					return '<b style="color:green;">' . $GLOBALS['LANG']->getLL('extConf.registered') . '</b>';
				}
			}
			return '<b style="color:green;">' . $GLOBALS['LANG']->getLL('extConf.authenticated') . '</b>';
		} else {
			return '<b style="color:red;">' . $GLOBALS['LANG']->getLL('extConf.noCredentials') . '</b>';
		}
	}

}

if(defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/immoscout2ttnews/classes/class.tx_immoscout2ttnews_emconfhelper.php'])) {
	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/immoscout2ttnews/classes/class.tx_immoscout2ttnews_emconfhelper.php']);
}
?>